@@ -33,6 +33,7 @@
 
 class ParseController;
 class CryptController;
+class Attachment;
 
 /** @brief Data wrapper around a mailitem.
  *
@@ -207,8 +208,12 @@ public:
       plaintext. returns the value of the oom close
       call. This may have delete the mail if the close
       triggers an unload.
+
+      Set restoreSMIMEClass to resotre the S/MIME
+      Message class IPM.Note.SMIME etc. for S/MIME
+      mails.
   */
-  static int close (Mail *mail);
+  int close (bool restoreSMIMEClass = true);
 
   /** @brief locate recipients for all crypto mails
     *
@@ -647,6 +652,7 @@ public:
 private:
   bool checkIfMailIsChildOfPrintMail_o ();
   void updateSigstate ();
+  int add_attachments_o (std::vector<std::shared_ptr<Attachment> > attachments);
 
   LPDISPATCH m_mailitem;
   LPDISPATCH m_event_sink;
@@ -702,5 +708,6 @@ private:
   bool m_decrypt_again; /* Mail should be decrypted again if it sees
                            another beforeread */
   bool m_printing; /* Mail is decrypted for printing */
+  std::string m_gpgol_class; /* The GpgOL Message class */
 };
 #endif // MAIL_H
