@@ -91,8 +91,8 @@ get_object_name (LPUNKNOWN obj)
     goto leave;
 
   /* We can't use gpgol_queryInterface here to avoid recursion */
-  obj->QueryInterface (IID_IDispatch, (void **)&disp);
-  if (!disp)
+  hr = obj->QueryInterface (IID_IDispatch, (void **)&disp);
+  if (!disp || hr != S_OK)
     goto leave;
 
   disp->GetTypeInfo (0, 0, &tinfo);
@@ -1494,7 +1494,8 @@ get_oom_recipients (LPDISPATCH recipients, bool *r_err)
    name that should be used in outlook. */
 int
 add_oom_attachment (LPDISPATCH disp, const wchar_t* inFileW,
-                    const wchar_t* displayName)
+                    const wchar_t* displayName, std::string &r_error_str,
+                    int *r_err_code)
 {
   TSTART;
   LPDISPATCH attachments = get_oom_object (disp, "Attachments");
@@ -1555,6 +1556,20 @@ add_oom_attachment (LPDISPATCH disp, const wchar_t* inFileW,
                  vtResult.pdispVal, vtResult.vt, (unsigned int)hr,
                  (unsigned int)argErr);
       dump_excepinfo (execpinfo);
+
+      if (r_err_code)
+        {
+          *r_err_code = (int) execpinfo.scode;
+        }
+      if (execpinfo.bstrDescription)
+        {
+          char *utf8Err = wchar_to_utf8 (execpinfo.bstrDescription);
+          if (utf8Err)
+            {
+              r_error_str = utf8Err;
+            }
+          xfree (utf8Err);
+        }
     }
 
   if (inFileB)
