@@ -796,20 +796,6 @@ HRESULT get_is_crypto_mail (LPDISPATCH ctrl, VARIANT *result)
   return S_OK;
 }
 
-HRESULT print_decrypted (LPDISPATCH ctrl)
-{
-  MY_MAIL_GETTER
-
-  if (!mail)
-    {
-      log_error ("%s:%s: Failed to get mail.",
-                 SRCNAME, __func__);
-      return S_OK;
-    }
-  invoke_oom_method (mail->item(), "PrintOut", NULL);
-  return S_OK;
-}
-
 HRESULT decrypt_permanently (LPDISPATCH ctrl)
 {
   MY_MAIL_GETTER
@@ -872,3 +858,26 @@ HRESULT override_file_close ()
 
   TRETURN S_OK;
 }
+
+bool g_ignore_next_load = false;
+
+HRESULT override_file_save_as (DISPPARAMS *parms)
+{
+  TSTART;
+  if (!parms)
+    {
+      STRANGEPOINT;
+      TRETURN S_OK;
+    }
+
+  /* Do not cancel the event so that the underlying File Save As works. */
+  parms->rgvarg[0].pvarVal->boolVal = VARIANT_FALSE;
+  /* File->SaveAs triggers an ItemLoad event immediately after this
+     callback. To avoid attaching our decrypt / save prevention code
+     on that mail we set this global variable so that application-events
+     knows that it should ignore the next item load. That way we do
+     not interfere and it can just save what is in MAPI (the encrypted
+     mail). */
+  g_ignore_next_load = true;
+  TRETURN S_OK;
+}
