@@ -47,11 +47,11 @@
 #define ID_GET_SIGN_ENCRYPT_PRESSED_EX 31
 #define ID_CMD_SIGN_ENCRYPT_MIME 32
 #define ID_CMD_SIGN_ENCRYPT_MIME_EX 33
-#define ID_CMD_PRINT_DECRYPTED 34
 #define ID_GET_IS_CRYPTO_MAIL 35
 #define ID_CMD_OPEN_CONTACT_KEY 36
 #define ID_CMD_FILE_CLOSE 37
 #define ID_CMD_DECRYPT_PERMANENTLY 38
+#define ID_CMD_FILE_SAVE_AS 39
 
 #define ID_BTN_DECRYPT           IDI_DECRYPT_16_PNG
 #define ID_BTN_DECRYPT_LARGE     IDI_DECRYPT_48_PNG
@@ -86,12 +86,12 @@ HRESULT get_crypto_icon (LPDISPATCH ctrl, VARIANT *result);
 HRESULT ribbon_loaded (LPDISPATCH ctrl);
 /* Is the currently selected mail a crypto mail ? */
 HRESULT get_is_crypto_mail (LPDISPATCH ctrl, VARIANT *result);
-/* Print out the decrypted mail */
-HRESULT print_decrypted (LPDISPATCH ctrl);
 /* Open key configuration for a contact */
 HRESULT open_contact_key (LPDISPATCH ctrl);
 /* An explorer is closed by File->Close */
 HRESULT override_file_close ();
 /* Decrypt permanently */
 HRESULT decrypt_permanently (LPDISPATCH ctrl);
+/* SaveAs from the file menu */
+HRESULT override_file_save_as (DISPPARAMS *parms);
 #endif
