@@ -40,8 +40,6 @@
 #define CHECK_MIN_INTERVAL (60 * 60 * 24 * 7)
 #define WKS_REG_KEY "webkey"
 
-#define DEBUG_WKS 1
-
 #undef _
 #define _(a) utf8_gettext (a)
 
@@ -62,8 +60,8 @@ WKSHelper::~WKSHelper ()
 {
   // Ensure that we are not destroyed while
   // worker is running.
-  gpgrt_lock_lock (&wks_lock);
-  gpgrt_lock_unlock (&wks_lock);
+  gpgol_lock (&wks_lock);
+  gpgol_unlock (&wks_lock);
 }
 
 const WKSHelper*
@@ -79,10 +77,10 @@ WKSHelper::instance ()
 WKSHelper::WKSState
 WKSHelper::get_state (const std::string &mbox) const
 {
-  gpgrt_lock_lock (&wks_lock);
+  gpgol_lock (&wks_lock);
   const auto it = s_states.find(mbox);
   const auto dataEnd = s_states.end();
-  gpgrt_lock_unlock (&wks_lock);
+  gpgol_unlock (&wks_lock);
   if (it == dataEnd)
     {
       return NotChecked;
@@ -93,10 +91,10 @@ WKSHelper::get_state (const std::string &mbox) const
 time_t
 WKSHelper::get_check_time (const std::string &mbox) const
 {
-  gpgrt_lock_lock (&wks_lock);
+  gpgol_lock (&wks_lock);
   const auto it = s_last_checked.find(mbox);
   const auto dataEnd = s_last_checked.end();
-  gpgrt_lock_unlock (&wks_lock);
+  gpgol_unlock (&wks_lock);
   if (it == dataEnd)
     {
       return 0;
@@ -107,18 +105,18 @@ WKSHelper::get_check_time (const std::string &mbox) const
 std::pair <GpgME::Data *, Mail *>
 WKSHelper::get_cached_confirmation (const std::string &mbox) const
 {
-  gpgrt_lock_lock (&wks_lock);
+  gpgol_lock (&wks_lock);
   const auto it = s_confirmation_cache.find(mbox);
   const auto dataEnd = s_confirmation_cache.end();
 
   if (it == dataEnd)
     {
-      gpgrt_lock_unlock (&wks_lock);
+      gpgol_unlock (&wks_lock);
       return std::make_pair (nullptr, nullptr);
     }
   auto ret = it->second;
   s_confirmation_cache.erase (it);
-  gpgrt_lock_unlock (&wks_lock);
+  gpgol_unlock (&wks_lock);
   return ret;
 }
 
@@ -248,14 +246,14 @@ do_check (LPVOID arg)
   if (success)
     {
       log_debug ("%s:%s: WKS client: '%s' is supported",
-                 SRCNAME, __func__, mbox.c_str ());
+                 SRCNAME, __func__, anonstr (mbox.c_str ()));
       isPublished = check_published (mbox);
     }
 
   if (isPublished)
     {
       log_debug ("%s:%s: WKS client: '%s' is published",
-                 SRCNAME, __func__, mbox.c_str ());
+                 SRCNAME, __func__, anonstr (mbox.c_str ()));
       state = WKSHelper::IsPublished;
     }
 
@@ -319,7 +317,8 @@ WKSHelper::load () const
       if (states.size() != 2)
         {
           log_error ("%s:%s: Invalid state '%s' for '%s'",
-                     SRCNAME, __func__, mbox.c_str (), pair.second.c_str ());
+                     SRCNAME, __func__, anonstr (mbox.c_str ()),
+                     anonstr (pair.second.c_str ()));
           continue;
         }
 
@@ -340,7 +339,7 @@ WKSHelper::load () const
 void
 WKSHelper::save () const
 {
-  gpgrt_lock_lock (&wks_lock);
+  gpgol_lock (&wks_lock);
   for (const auto &pair: s_states)
     {
       auto state = std::to_string (pair.second) + ';';
@@ -361,7 +360,7 @@ WKSHelper::save () const
                      SRCNAME, __func__);
         }
     }
-  gpgrt_lock_unlock (&wks_lock);
+  gpgol_unlock (&wks_lock);
 }
 
 static DWORD WINAPI
@@ -380,7 +379,7 @@ do_notify (LPVOID arg)
 void
 WKSHelper::allow_notify (int sleepTimeMS) const
 {
-  gpgrt_lock_lock (&wks_lock);
+  gpgol_lock (&wks_lock);
   for (auto &pair: s_states)
     {
       if (pair.second == ConfirmationSeen ||
@@ -394,7 +393,7 @@ WKSHelper::allow_notify (int sleepTimeMS) const
           break;
         }
     }
-  gpgrt_lock_unlock (&wks_lock);
+  gpgol_unlock (&wks_lock);
 }
 
 void
@@ -434,7 +433,7 @@ WKSHelper::notify (const char *cBox) const
     }
 
   log_debug ("%s:%s: Unhandled notify state: %i for '%s'",
-             SRCNAME, __func__, state, cBox);
+             SRCNAME, __func__, state, anonstr (cBox));
   return;
 }
 
@@ -505,10 +504,8 @@ WKSHelper::start_publish (const std::string &mbox) const
       return;
     }
 
-#ifdef DEBUG_WKS
-  log_debug ("%s:%s: WKS client: returned '%s'",
+  log_data ("%s:%s: WKS client: returned '%s'",
              SRCNAME, __func__, data.c_str ());
-#endif
 
   if (!send_mail (data))
     {
@@ -526,7 +523,7 @@ void
 WKSHelper::update_state (const std::string &mbox, WKSState state,
                          bool store) const
 {
-  gpgrt_lock_lock (&wks_lock);
+  gpgol_lock (&wks_lock);
   auto it = s_states.find(mbox);
 
   if (it != s_states.end())
@@ -537,7 +534,7 @@ WKSHelper::update_state (const std::string &mbox, WKSState state,
     {
       s_states.insert (std::make_pair (mbox, state));
     }
-  gpgrt_lock_unlock (&wks_lock);
+  gpgol_unlock (&wks_lock);
 
   if (store)
     {
@@ -549,7 +546,7 @@ void
 WKSHelper::update_last_checked (const std::string &mbox, time_t time,
                                 bool store) const
 {
-  gpgrt_lock_lock (&wks_lock);
+  gpgol_lock (&wks_lock);
   auto it = s_last_checked.find(mbox);
   if (it != s_last_checked.end())
     {
@@ -559,7 +556,7 @@ WKSHelper::update_last_checked (const std::string &mbox, time_t time,
     {
       s_last_checked.insert (std::make_pair (mbox, time));
     }
-  gpgrt_lock_unlock (&wks_lock);
+  gpgol_unlock (&wks_lock);
 
   if (store)
     {
@@ -643,7 +640,7 @@ WKSHelper::send_mail (const std::string &mimeData) const
   if (account)
     {
       log_debug ("%s:%s: Found account to change for '%s'.",
-                 SRCNAME, __func__, from.c_str ());
+                 SRCNAME, __func__, anonstr (from.c_str ()));
       put_oom_disp (mail, "SendUsingAccount", account);
     }
   gpgol_release (account);
@@ -765,10 +762,9 @@ WKSHelper::handle_confirmation_notify (const std::string &mbox) const
       return;
     }
 
-#ifdef DEBUG_WKS
-  log_debug ("%s:%s: WKS client: returned '%s'",
-             SRCNAME, __func__, data.c_str ());
-#endif
+  log_data ("%s:%s: WKS client: returned '%s'",
+            SRCNAME, __func__, data.c_str ());
+
   if (!send_mail (data))
    {
      gpgol_message_box (get_active_hwnd (),
@@ -841,9 +837,9 @@ WKSHelper::handle_confirmation_read (Mail *mail, LPSTREAM stream) const
   /* And reset it to start */
   mystdin->seek (0, SEEK_SET);
 
-  gpgrt_lock_lock (&wks_lock);
+  gpgol_lock (&wks_lock);
   s_confirmation_cache.insert (std::make_pair (mbox, std::make_pair (mystdin, mail)));
-  gpgrt_lock_unlock (&wks_lock);
+  gpgol_unlock (&wks_lock);
 
   update_state (mbox, ConfirmationSeen);
 
